# ***J***ust ***a***nother ***v***ampire ***A***pi #

  As same as bloodhound let us reimplement the Java API.
  This is similar to long time ago [JavAPI](https://github.com/RealBastie/JavApi) project.
  
  ## The Idea ##
  Too many good programming languages are looking for developers hype. Maybe You 
  believe to coding in all important languages. I want to take a good or the best
  language for my problem. But why the have different API interfaces? Why I can
  not only learn the syntax and a little bit semantic?
  
  ## The Java way ##
  It think it is a good way to take a look into a new programming language to reimplement
  something. Java was great - perhaps Java is great, maybe not longer more. I don't no,
  but I learned Java before the year 2000. So I know the old API good enough to reimplement.
  
  Just like a vampire take the good base of Java, the API declaration and **do the hard
  work: implement the code behind.** 
  
  ## The reason ##
  I like many programming languages or parts of these - Java, C#, Rust, COBOL, PHP, Swift,...
  But I like to create a solution for a problem more than using one single programming language.
  And I believe we do not need more programmer, we need the right programmer this time.
  I think with natural language processing and the power of computer we can develop with
  description of problems in natural language.
  
  Python is a programming language with many natural language processing API. So I take 
  Python and Java is the (or with COBOL one of) backend programming languages.
  
  ## API description ##
  If a class and method is defined, take a look to Java API documentation.
     
